@@ -5,40 +5,29 @@ package App::Pinto;
 use strict;
 use warnings;
 
-use Encode;
 use Class::Load;
-use Term::Prompt;
-use List::Util qw(min);
-use Log::Dispatch::Screen;
-use Log::Dispatch::Screen::Color;
-
-use Pinto::Constants qw(:all);
-
 use App::Cmd::Setup -app;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.054'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub global_opt_spec {
 
     return (
-        [ 'root|r=s'     => 'Path to your repository root directory'  ],
-        [ 'nocolor'      => 'Do not colorize diagnostic messages'     ],
-        [ 'password|p=s' => 'Password for server authentication'      ],
-        [ 'quiet|q'      => 'Only report fatal errors'                ],
-        [ 'username|u=s' => 'Username for server authentication'      ],
-        [ 'verbose|v+'   => 'More diagnostic output (repeatable)'     ],
+        [ 'root|r=s'           => 'Path to your repository root directory'  ],
+        [ 'no-color|no-colour' => 'Do not colorize any output'              ],
+        [ 'password|p=s'       => 'Password for server authentication'      ],
+        [ 'quiet|q'            => 'Only report fatal errors'                ],
+        [ 'username|u=s'       => 'Username for server authentication'      ],
+        [ 'verbose|v+'         => 'More diagnostic output (repeatable)'     ],
     );
-
-    # TODO: Add options for color contols!
 }
 
 #------------------------------------------------------------------------------
 
-
 sub pinto {
     my ($self) = @_;
 
@@ -51,25 +40,10 @@ sub pinto {
         $global_options->{password} = $self->_prompt_for_password
             if defined $global_options->{password} and $global_options->{password} eq '-';
 
-        # Translating (progressive) verbose values into (regressive) log_level values.
-        # Note that we must not pass log_level into the constructor for Pinto, or it
-        # will set the logging level for its own internal logs.
-
-        my $logger_options = {};
-        $logger_options->{log_level} = 3 - min(delete $global_options->{verbose} || 0, 3);
-        $logger_options->{log_level} = 4 if delete $global_options->{quiet};
-        $logger_options->{nocolor}   = 1 if delete $global_options->{nocolor};
-
-        # TODO: Give helpful error message if the right backend
-        # is not installed.
-
         my $pinto_class = $self->pinto_class_for($global_options->{root});
         Class::Load::load_class($pinto_class);
 
-        my $pinto = $pinto_class->new( %{ $global_options } );
-        $pinto->add_logger($self->make_logger( %{ $logger_options } ));
-
-        $pinto;
+        $pinto_class->new( %{ $global_options } );
     };
 }
 
@@ -82,42 +56,12 @@ sub pinto_class_for {
 
 #------------------------------------------------------------------------------
 
-sub make_logger {
-    my ($self, %options) = @_;
-
-    my $nocolor   = $options{nocolor};
-    my $colors    = $nocolor ? {} : ($self->log_colors);
-    my $log_class = 'Log::Dispatch::Screen';
-    $log_class   .= '::Color' unless $nocolor;
-
-    my $log_level = $options{log_level};
-
-    return $log_class->new( min_level => $log_level,
-                            color     => $colors,
-                            stderr    => 1,
-                            newline   => 1 );
-}
-
-#------------------------------------------------------------------------------
-
-sub log_colors {
-    my ($self) = @_;
-
-    # TODO: Create command line options for controlling colors and
-    # process them here.
-
-    return $self->default_log_colors;
-}
-
-#------------------------------------------------------------------------------
-
-sub default_log_colors { return $PINTO_DEFAULT_LOG_COLORS }
-
-#------------------------------------------------------------------------------
-
 sub _prompt_for_password {
    my ($self) = @_;
 
+   require Encode;
+   require Term::Prompt;
+
    my $input    = Term::Prompt::prompt('p', 'Password:', '', '');
    my $password = Encode::decode_utf8($input);
    print "\n"; # Get on a new line
@@ -130,11 +74,11 @@ sub _prompt_for_password {
 
 1;
 
-
+__END__
 
 =pod
 
-=for :stopwords Jeffrey Thalhammer Imaginative Software Systems cpan testmatrix url
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems cpan testmatrix url
 annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
 placeholders metacpan
 
@@ -144,7 +88,7 @@ App::Pinto - Command-line driver for Pinto
 
 =head1 VERSION
 
-version 0.054
+version 0.066
 
 =head1 DESCRIPTION
 
@@ -157,21 +101,16 @@ host that is running L<pintod>, then install L<Pinto::Remote>.  If
 you're not sure what you need, then install L<Task::Pinto> to get the
 whole kit.
 
-=head1 METHODS
-
-=head2 pinto
-
-Returns a reference to a L<Pinto> or L<Pinto::Remote> object that has
-been constructed for this application.
-
 =head1 SEE ALSO
 
-L<Pinto::Manual> for general information on using Pinto.
-
 L<pinto> to create and manage a Pinto repository.
 
 L<pintod> to allow remote access to your Pinto repository.
 
+L<Pinto::Manual> for general information on using Pinto.
+
+L<Stratopan|http://stratopan.com> for hosting your Pinto repository in the cloud.
+
 =head1 SUPPORT
 
 =head2 Perldoc
@@ -242,7 +181,7 @@ L<https://github.com/thaljef/App-Pinto>
 
 =head1 AUTHOR
 
-Jeffrey Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -252,7 +191,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
