@@ -14,7 +14,7 @@ use App::Cmd::Setup -command;
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.054'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -124,11 +124,11 @@ sub command_namespace_prefix { return __PACKAGE__ }
 #-----------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
-=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -136,11 +136,11 @@ App::Pinto::Command - Base class for pinto commands
 
 =head1 VERSION
 
-version 0.054
+version 0.066
 
 =head1 AUTHOR
 
-Jeffrey Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -150,6 +150,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
