@@ -11,17 +11,17 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.054'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 #-----------------------------------------------------------------------------
 
 1;
 
-
+__END__
 
 =pod
 
-=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -29,7 +29,7 @@ App::Pinto::Command::clean - remove orphaned distribution archives
 
 =head1 VERSION
 
-version 0.054
+version 0.066
 
 =head1 SYNOPSIS
 
@@ -40,12 +40,16 @@ version 0.054
 The database for L<Pinto> is transactional, so failures and aborted
 commands do not change the indexes.  However, the filesystem where
 distribution archives are physically stored is not transactional and
-may become cluttered with archives that are not on any stack.
+may become cluttered with archives that are not in the database.
 
 Normally, L<Pinto> tries to clean up those orphaned archives.  But in
 some cases it might not.  Running this command will force their
 removal.
 
+This command also runs some optimizations on the database.  So if
+your repository seems to be running slowly, try running this command
+to see if performance improves.
+
 =head1 COMMAND ARGUMENTS
 
 None.
@@ -56,7 +60,7 @@ None.
 
 =head1 AUTHOR
 
-Jeffrey Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -66,7 +70,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
