@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.054'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -24,7 +24,7 @@ sub opt_spec {
         [ 'local-lib|l=s'           => 'install into a local lib directory'           ],
         [ 'local-lib-contained|L=s' => 'install into a contained local lib directory' ],
         [ 'message|m=s'             => 'Message to describe the change'               ],
-        [ 'pull'                    => 'pull missing prereqs onto the stack first'    ],
+        [ 'do-pull'                 => 'pull missing prereqs onto the stack first'    ],
         [ 'stack|s=s'               => 'Use the index for this stack'                 ],
 
     );
@@ -46,9 +46,6 @@ sub validate_args {
     $self->usage_error('--message is only useful with --pull')
         if $opts->{message} and not $opts->{pull};
 
-    $self->usage_error('--dryrun is only useful with --pull')
-        if $opts->{dryrun} and not $opts->{pull};
-
     return 1;
 }
 
@@ -63,11 +60,11 @@ sub args_from_stdin { return 1 }
 #------------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
-=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems exe cpanm
 
 =head1 NAME
 
@@ -75,12 +72,11 @@ App::Pinto::Command::install - install stuff from the repository
 
 =head1 VERSION
 
-version 0.054
+version 0.066
 
 =head1 SYNOPSIS
 
   pinto --root=REPOSITORY_ROOT install [OPTIONS] TARGET...
-  pinto --root=REPOSITORY_ROOT install [OPTIONS] < LIST_OF_TARGETS
 
 =head1 DESCRIPTION
 
@@ -125,11 +121,11 @@ version 1.500 or newer is required.
 =item -o NAME=VALUE
 
 These are options that you wish to pass to L<cpanm>.  Do not prefix
-the option name with a '-'.  You can pass any option you like, but the
+the option NAME with a '-'.  You can pass any option you like, but the
 C<--mirror> and C<--mirror-only> options will always be set to point
 to the Pinto repository.
 
-=item --dryrun
+=item --dry-run
 
 Go through all the motions, but do not actually commit any changes to
 the repository.  Use this option to see how the command would
@@ -160,12 +156,12 @@ if you also set the C<--pull> option.  If you do not use C<--message>
 option, then you will be prompted to enter the message via your text
 editor.  Use the C<EDITOR> or C<VISUAL> environment variables to
 control which editor is used.  A log message is not required whenever
-the C<--dryrun> option is set, or if the action did not yield any
+the C<--dry-run> option is set, or if the action did not yield any
 changes to the repository.
 
 =item --pull
 
-Recursively Pull prerequsiste packages (or the targets themselves)
+Recursively pull prerequisite packages (or the targets themselves)
 onto the stack before installing.  Without the C<--pull> option, all
 prerequisites must already be on the stack.  See the
 L<pull|App::Pinto::Command::pull> command to explicitly pull packages
@@ -185,9 +181,47 @@ the repository.
 
 =back
 
+=head1 USING cpan OR cpanm DIRECTLY
+
+On the surface, A Pinto repository looks like an ordinary CPAN repository,
+so you can use any client to install modules.  All you have to do is "point" 
+it at the URL of your Pinto repository.  Each client has a slightly different 
+interface for setting the URL.
+
+For L<cpanm>, use the C<--mirror> and C<--mirror-only> options like this:
+
+  $> cpanm --mirror file:///path/to/repo --mirror-only Some::Package ...
+
+For L<cpan>, set the C<urllist> config option via the shell like this:
+
+  $> cpan
+  cpan[1]> o conf urllist file:///path/to/repo
+  cpan[2]> reload index
+  cpan[3]> install Some::Package
+  cpan[4]> o conf commit     # If you want to make the change permanent
+
+Pointing your client at the top of your repository will install modules
+from the default stack.  To install from a particular stack, just add it 
+to the URL.  For example:
+
+  file:///path/to/repo                # Install from default stack
+  file:///path/to/repo/stacks/dev     # Install from "dev" stack
+  file:///path/to/repo/stacks/prod    # Install from "prod" stack
+
+If your repository does not have a default stack then you must specify the
+full URL to one of the stacks as shown above.
+
+=head1 COMPATIBILITY
+
+The C<install> does not support some of the newer features found in
+version 1.6 (or later) of L<cpanm>, such as installing from a Git 
+repository, installing development releases, or using complex version 
+expressions. If you pass any of those as arguments to this command, the 
+behavior is unspecified.
+
 =head1 AUTHOR
 
-Jeffrey Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -197,7 +231,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
