@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.054'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -19,13 +19,9 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'default'         => 'Make the new stack the default stack' ],
-        [ 'description|d=s' => 'Brief description of the stack'       ],
-        [ 'message|m=s'     => 'Message to describe the change'       ],
-        [ 'use-default-message|M' => 'Use the generated message'      ],
+        [ 'default'               => 'Make the new stack the default stack' ],
+        [ 'description|d=s'       => 'Brief description of the stack'       ],
     );
-
-
 }
 
 #------------------------------------------------------------------------------
@@ -36,28 +32,19 @@ sub validate_args {
     $self->usage_error('Must specify exactly one stack')
         if @{$args} != 1;
 
+    $opts->{stack} = $args->[0];
+
     return 1;
 }
 
-#------------------------------------------------------------------------------
-
-sub execute {
-    my ($self, $opts, $args) = @_;
-
-    my $result = $self->pinto->run($self->action_name, %{$opts},
-                                                       stack => $args->[0]);
-
-    return $result->exit_status;
-}
-
 #------------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
-=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -65,7 +52,7 @@ App::Pinto::Command::new - create a new empty stack
 
 =head1 VERSION
 
-version 0.054
+version 0.066
 
 =head1 SYNOPSIS
 
@@ -75,10 +62,9 @@ version 0.054
 
 This command creates a new empty stack.
 
-Please see the L<copy|App::Pinto::Command::copy> command to
-create a new stack from another one, or the
-L<edit|App::Pinto::Command::edit> command to change a
-stack's properties after it has been created.
+See the L<copy|App::Pinto::Command::copy> command to create a new 
+stack from another one, or the L<props|App::Pinto::Command::props> 
+command to change a stack's properties after it has been created.
 
 =head1 COMMAND ARGUMENTS
 
@@ -98,33 +84,13 @@ Also mark the new stack as the default stack.
 
 =item -d TEXT
 
-Use TEXT for the description of the stack.  This is usually used to
-help explain the purpose of the stack.
-
-=item --message=TEXT
-
-=item -m TEXT
-
-Use TEXT as the revision history log message.  If you do not use the
-C<--message> option or the C<--use-default-message> option, then you
-will be prompted to enter the message via your text editor.  Use the
-C<EDITOR> or C<VISUAL> environment variables to control which editor
-is used.
-
-=item --use-default-message
-
-=item -M
-
-Use the default value for the revision history log message.  Pinto
-will generate a semi-informative log message just based on the command
-and its arguments.  If you set an explicit message with C<--message>,
-the C<--use-default-message> option will be silently ignored.
+Use TEXT for the description of the stack.
 
 =back
 
 =head1 AUTHOR
 
-Jeffrey Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -134,8 +100,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
