@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.054'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -19,9 +19,9 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'dryrun'      => 'Do not commit any changes'            ],
+        [ 'dry-run'     => 'Do not commit any changes'            ],
         [ 'message|m=s' => 'Message to describe the change'       ],
-        [ 'stack|s=s'   => 'Stack from which to unpin the target' ],
+        [ 'stack|s=s'   => 'Unpin targets from this stack'        ],
         [ 'use-default-message|M' => 'Use the generated message'  ],
     );
 }
@@ -38,11 +38,11 @@ sub args_from_stdin { return 1 }
 
 1;
 
-
+__END__
 
 =pod
 
-=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -50,12 +50,11 @@ App::Pinto::Command::unpin - free packages that have been pinned
 
 =head1 VERSION
 
-version 0.054
+version 0.066
 
 =head1 SYNOPSIS
 
   pinto --root=REPOSITORY_ROOT unpin [OPTIONS] TARGET ...
-  pinto --root=REPOSITORY_ROOT unpin [OPTIONS] < LIST_OF_TARGETS
 
 =head1 DESCRIPTION
 
@@ -76,7 +75,7 @@ specified as packages or distributions, such as:
 
 When unpinning a distribution, all the packages in that distribution
 become unpinned.  Likewise when unpinning a package, all its sister
-packages in the same distributon also become unpinned.
+packages in the same distribution also become unpinned.
 
 You can also pipe arguments to this command over STDIN.  In that case,
 blank lines and lines that look like comments (i.e. starting with "#"
@@ -86,7 +85,7 @@ or ';') will be ignored.
 
 =over 4
 
-=item --dryrun
+=item --dry-run
 
 Go through all the motions, but do not actually commit any changes to
 the repository.  Use this option to see how the command would
@@ -100,7 +99,7 @@ Use TEXT as the revision history log message.  If you do not use the
 C<--message> option or the C<--use-default-message> option, then you
 will be prompted to enter the message via your text editor.  Use the
 C<EDITOR> or C<VISUAL> environment variables to control which editor
-is used.  A log message is not required whenever the C<--dryrun>
+is used.  A log message is not required whenever the C<--dry-run>
 option is set, or if the action did not yield any changes to the
 repository.
 
@@ -124,7 +123,7 @@ the C<--use-default-message> option will be silently ignored.
 
 =head1 AUTHOR
 
-Jeffrey Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -134,8 +133,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
