@@ -11,17 +11,17 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.054'; # VERSION
+our $VERSION = '0.066'; # VERSION
 
 #-----------------------------------------------------------------------------
 
 1;
 
-
+__END__
 
 =pod
 
-=for :stopwords Jeffrey Thalhammer Imaginative Software Systems
+=for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems
 
 =head1 NAME
 
@@ -29,7 +29,7 @@ App::Pinto::Command::verify - report archives that are missing
 
 =head1 VERSION
 
-version 0.054
+version 0.066
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ None
 
 =head1 AUTHOR
 
-Jeffrey Thalhammer <jeff@imaginative-software.com>
+Jeffrey Ryan Thalhammer <jeff@stratopan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -67,7 +67,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
